@@ -22,7 +22,9 @@ from neutron_lib.api import validators
 from neutron_lib import constants as n_constants
 from neutron_lib.db import constants as db_const
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
+from neutron_lib.services import base as service_base
 from oslo_config import cfg
 from oslo_log import log as logging
 import six
@@ -30,9 +32,7 @@ import six
 from neutron.api import extensions
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron.plugins.common import constants
 from neutron.quota import resource_registry
-from neutron.services import service_base
 
 from neutron_lbaas._i18n import _
 from neutron_lbaas.services.loadbalancer import constants as lb_const
@@ -440,10 +440,6 @@ class Loadbalancerv2(api_extensions.ExtensionDescriptor):
     def get_description(cls):
         return "Extension for LoadBalancing service v2"
 
-    @classmethod
-    def get_namespace(cls):
-        return "http://wiki.openstack.org/neutron/LBaaS/API_2.0"
-
     @classmethod
     def get_updated(cls):
         return "2014-06-18T10:00:00-00:00"
@@ -634,6 +630,7 @@ class LoadBalancerPluginBaseV2(service_base.ServicePluginBase):
     def statuses(self, context, loadbalancer_id):
         pass
 
+    @abc.abstractmethod
     def get_l7policies(self, context, filters=None, fields=None):
         pass
 
