@@ -79,6 +79,10 @@ class BaseTestCase(manager.NetworkScenarioTest):
         self.num = 50
         self.server_fixed_ips = {}
 
+        self.listener_protocol = config.lbaas.default_listener_protocol
+        self.pool_protocol = config.lbaas.default_pool_protocol
+        self.hm_protocol = config.lbaas.default_health_monitor_protocol
+
         self._create_security_group_for_test()
         self._set_net_and_subnet()
 
@@ -118,13 +122,13 @@ class BaseTestCase(manager.NetworkScenarioTest):
         """
         tenant_id = self.networks_client.tenant_id
         try:
-            tenant_net = self.admin_manager.networks_client.list_networks(
+            tenant_net = self.os_admin.networks_client.list_networks(
                 tenant_id=tenant_id)['networks'][0]
         except IndexError:
             tenant_net = None
 
         if tenant_net:
-            self.subnet = self.admin_manager.subnets_client.list_subnets(
+            self.subnet = self.os_admin.subnets_client.list_subnets(
                 tenant_id=tenant_id)['subnets'][0]
             self.addCleanup(test_utils.call_and_ignore_notfound_exc,
                             self.networks_client.delete_network,
@@ -137,7 +141,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
             # with the fixed network is the one we want.  In the future, we
             # should instead pull a subnet id from config, which is set by
             # devstack/admin/etc.
-            subnet = self.admin_manager.subnets_client.list_subnets(
+            subnet = self.os_admin.subnets_client.list_subnets(
                 network_id=self.network['id'])['subnets'][0]
             self.subnet = subnet
 
@@ -248,11 +252,11 @@ class BaseTestCase(manager.NetworkScenarioTest):
                     'Content-Type: text/html; '
                     'charset=UTF-8\r\n\r\n%(server)s"; cat >/dev/null')
 
-            with tempfile.NamedTemporaryFile() as script:
+            with tempfile.NamedTemporaryFile(mode='w+') as script:
                 script.write(resp % {'s_id': server_name[-1],
                                      'server': server_name})
                 script.flush()
-                with tempfile.NamedTemporaryFile() as key:
+                with tempfile.NamedTemporaryFile(mode='w+') as key:
                     key.write(private_key)
                     key.flush()
                     self.copy_file_to_host(script.name,
@@ -269,11 +273,11 @@ class BaseTestCase(manager.NetworkScenarioTest):
             ssh_client.exec_command(cmd)
 
             if len(self.server_ips) == 1:
-                with tempfile.NamedTemporaryFile() as script:
+                with tempfile.NamedTemporaryFile(mode='w+') as script:
                     script.write(resp % {'s_id': 2,
                                          'server': 'server2'})
                     script.flush()
-                    with tempfile.NamedTemporaryFile() as key:
+                    with tempfile.NamedTemporaryFile(mode='w+') as key:
                         key.write(private_key)
                         key.flush()
                         self.copy_file_to_host(script.name,
@@ -283,12 +287,11 @@ class BaseTestCase(manager.NetworkScenarioTest):
                                       'script': 'script2'}
                 ssh_client.exec_command(cmd)
 
-    def _create_listener(self, load_balancer_id, port=80, protocol='HTTP',
-                         **kwargs):
+    def _create_listener(self, load_balancer_id, port=80, **kwargs):
         """Create a listener with HTTP protocol listening on port 80."""
         self.listener = self.listeners_client.create_listener(
-            loadbalancer_id=load_balancer_id,
-            protocol=protocol, protocol_port=port, **kwargs)
+            loadbalancer_id=load_balancer_id, protocol=self.listener_protocol,
+            protocol_port=port, **kwargs)
         self.assertTrue(self.listener)
         self.addCleanup(self._cleanup_listener, self.listener.get('id'),
                         load_balancer_id=load_balancer_id)
@@ -297,7 +300,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
     def _create_health_monitor(self):
         """Create a pool with ROUND_ROBIN algorithm."""
         self.hm = self.health_monitors_client.create_health_monitor(
-            type='HTTP', max_retries=5, delay=3, timeout=5,
+            type=self.hm_protocol, max_retries=5, delay=3, timeout=5,
             pool_id=self.pool['id'])
         self.assertTrue(self.hm)
         self.addCleanup(self._cleanup_health_monitor,
@@ -310,7 +313,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
         pool = {
             "listener_id": listener_id,
             "lb_algorithm": "ROUND_ROBIN",
-            "protocol": "HTTP"
+            "protocol": self.pool_protocol
         }
         if persistence_type:
             pool.update({'session_persistence': {'type': persistence_type}})
@@ -526,7 +529,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
         for i in range(self.num):
             try:
                 server = urllib2.urlopen("http://{0}/".format(vip_ip),
-                                         None, 2).read()
+                                         None, 2).read().decode('utf8')
                 counters[server] += 1
             # HTTP exception means fail of server, so don't increase counter
             # of success and continue connection tries
@@ -614,7 +617,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
                "-i %(pkey)s %(file1)s %(dest)s" % {'pkey': pkey,
                                                    'file1': file_from,
                                                    'dest': dest})
-        args = shlex.split(cmd.encode('utf-8'))
+        args = shlex.split(cmd)
         subprocess_args = {'stdout': subprocess.PIPE,
                            'stderr': subprocess.STDOUT}
         proc = subprocess.Popen(args, **subprocess_args)
